@@ -1,7 +1,6 @@
 #include <sys/types.h>
 
 #include <err.h>
-#include <limits.h>
 #include <stdint.h>
 #include <stdio.h>
 #include <string.h>
@@ -66,15 +65,3 @@ xwrite(int fd, const void *buf, size_t nbytes)
 	}
 	return total;
 }
-
-int
-mul_overflow(size_t a, size_t b)
-{
-	return a > SIZE_MAX / b;
-}
-
-int
-add_overflow(size_t a, size_t b)
-{
-	return a > SIZE_MAX - b;
-}
